@@ -9,6 +9,10 @@ from OpenSSL import crypto
 from pycfdi_credentials.utils import is_der, is_pem
 
 
+class CertificateException(Exception):
+    """Handle certificate load exceptions"""
+
+
 @dataclass
 class Subject:
     name: str
@@ -85,7 +89,7 @@ class Certificate:
             return crypto.load_certificate(crypto.FILETYPE_ASN1, content)
         if is_pem(content):
             return crypto.load_certificate(crypto.FILETYPE_PEM, content)
-        raise Exception("Not a valid certificate")
+        raise CertificateException("Not a valid certificate")
 
     def to_pem(self):
         return crypto.dump_certificate(crypto.FILETYPE_PEM, self.certificate)
